@@ -35,16 +35,16 @@ def regex_check(address: EmailAddress) -> bool:
     if not USER_REGEX.match(address.user):
         raise AddressFormatError
 
-    # Validate domain part: a) hostname.
-    if HOST_REGEX.match(address.ace_domain):
-        return True
+    # Validate domain part.
+    if address.domain_literal_ip:
+        literal_match = LITERAL_REGEX.match(address.ace_domain)
+        if literal_match is None:
+            raise AddressFormatError
+        if not _validate_ipv46_address(literal_match[1]):
+            raise AddressFormatError
+    else:
+        if HOST_REGEX.match(address.ace_domain) is None:
+            raise AddressFormatError
 
-    # Validate domain part: b) literal IP address.
-    literal_match = LITERAL_REGEX.match(address.ace_domain)
-    if literal_match:
-        ip_address = literal_match.group(1)
-        if _validate_ipv46_address(ip_address):
-            return True
-
-    # Domain part not successfully validated.
-    raise AddressFormatError
+    # All validations successful.
+    return True
