@@ -15,7 +15,7 @@ def validate_email_or_fail(
         email_address: str, check_regex: bool = True, check_mx: bool = True,
         from_address: Optional[str] = None, helo_host: Optional[str] = None,
         smtp_timeout: int = 10, dns_timeout: int = 10,
-        use_blacklist: bool = True) -> Optional[bool]:
+        use_blacklist: bool = True, debug: bool = False) -> Optional[bool]:
     """
     Return `True` if the email address validation is successful, `None` if the
     validation result is ambigious, and raise an exception if the validation
@@ -37,7 +37,7 @@ def validate_email_or_fail(
     return mx_check(
         email_address=email_address, from_address=from_address,
         helo_host=helo_host, smtp_timeout=smtp_timeout,
-        dns_timeout=dns_timeout)
+        dns_timeout=dns_timeout, debug=debug)
 
 
 def validate_email(email_address: str, *args, **kwargs):
